@@ -11,8 +11,8 @@ import (
 	"time"
 
 	"github.com/golang/glog"
-	"github.com/stolostron/insights-client/pkg/config"
-	"github.com/stolostron/insights-client/pkg/types"
+	"github.com/open-cluster-management/insights-client/pkg/config"
+	"github.com/open-cluster-management/insights-client/pkg/types"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
