@@ -9,7 +9,7 @@ import (
 	"testing"
 
 	sanitize "github.com/kennygrant/sanitize"
-	"github.com/stolostron/insights-client/pkg/types"
+	"github.com/open-cluster-management/insights-client/pkg/types"
 	"github.com/stretchr/testify/assert"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	clusterv1 "open-cluster-management.io/api/cluster/v1"
