@@ -12,16 +12,17 @@ import (
 	"testing"
 
 	"github.com/kennygrant/sanitize"
-	"github.com/stolostron/insights-client/pkg/retriever"
-	"github.com/stolostron/insights-client/pkg/types"
-	mocks "github.com/stolostron/insights-client/pkg/utils"
+	"github.com/open-cluster-management/insights-client/pkg/retriever"
+	"github.com/open-cluster-management/insights-client/pkg/types"
+	mocks "github.com/open-cluster-management/insights-client/pkg/utils"
 	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/apimachinery/pkg/runtime/schema"
 	dynamicfakeclient "k8s.io/client-go/dynamic/fake"
-	"sigs.k8s.io/wg-policy-prototypes/policy-report/api/v1alpha2"
+	"sigs.k8s.io/wg-policy-prototypes/policy-report/pkg/api/wgpolicyk8s.io/v1alpha2"
 )
 
 func UnmarshalFile(filepath string, resourceType interface{}, t *testing.T) {
@@ -79,7 +80,10 @@ func setUp(t *testing.T) {
 	scheme.AddKnownTypes(corev1.SchemeGroupVersion, &corev1.Namespace{})
 	scheme.AddKnownTypes(v1alpha2.SchemeGroupVersion, &v1alpha2.PolicyReport{})
 
-	fakeDynamicClient = dynamicfakeclient.NewSimpleDynamicClient(scheme, namespace)
+	gvrToListKind := map[schema.GroupVersionResource]string{
+		{Group: "policy.open-cluster-management.io", Version: "v1", Resource: "policies"}: "PolicyList",
+	}
+	fakeDynamicClient = dynamicfakeclient.NewSimpleDynamicClientWithCustomListKinds(scheme, gvrToListKind, namespace)
 
 	processor = NewProcessor()
 	fmt.Println("Setup complete")
